%global _hardened_build 1

Name:           davfs2
Version:        1.4.7
Release:        8%{?dist}
Summary:        A filesystem driver for WebDAV
Group:          System Environment/Base
License:        GPLv2+
URL:            http://savannah.nongnu.org/projects/davfs2
Source0:        http://download.savannah.gnu.org/releases/davfs2/davfs2-1.4.7.tar.gz
Patch1:         davfs2-1.4.7-neon-0.30.patch
Patch2:         davfs2-1.4.7-system.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  neon-devel gettext
Requires(pre):  shadow-utils

%define cachedir /var/cache/davfs2
%define piddir /var/run/mount.davfs
%define username davfs2
%define groupname %{username}

%description
davfs2 is a Linux file system driver that allows you to mount a WebDAV server
as a disk drive.

%prep
%setup -q
# Add support for neon 0.30.0
%patch1 -p1
# CVE-2013-4362: "Unsecure use of system()"
%patch2 -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure ssbindir=%{_sbindir}
make


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
%find_lang %{name}
# Create directories used by mount.davfs
install -d %{buildroot}%{cachedir} %{buildroot}%{piddir}
# Don't need this - we'll do our own doc install, thanks
rm -rf %{buildroot}/usr/share/doc/davfs2
# Remove suid bit, to work around a problem with brp-strip on suid binaries
chmod 0755 %{buildroot}/%{_sbindir}/mount.davfs
# UTF8ify translated man pages
find %{buildroot}/%{_mandir}/{de,es} -name "*.[58].gz" | while read m; do 
  gzip -dc $m | iconv -f "ISO8859-15" -t "UTF-8" - -o - | gzip -c9 > $m.utf8
  mv -f $m.utf8 $m
done
#symlinks for el6
%if 0%{?rhel} == 6
mkdir -p %{buildroot}/sbin
ln -s /%{_sbindir}/mount.davfs %{buildroot}/sbin/mount.davfs
ln -s /%{_sbindir}/umount.davfs %{buildroot}/sbin/umount.davfs
%endif

%clean
rm -rf %{buildroot}

%pre
getent group  %{groupname} >/dev/null || groupadd -r %{groupname}
getent passwd %{username} >/dev/null || \
  useradd -r -g %{groupname} -d %{cachedir} -s /sbin/nologin \
          -c "User account for %{name}" %{username}
exit 0


%files -f %{name}.lang
%defattr(-,root,root,-)
# Docs
%doc AUTHORS BUGS COPYING ChangeLog FAQ INSTALL NEWS README README.translators THANKS TODO
%{_mandir}/man5/*.gz
%{_mandir}/man8/*.gz
# localized man pages
%{_mandir}/*/man5/*.gz
%{_mandir}/*/man8/*.gz

# Configfiles etc.
%config(noreplace) %{_sysconfdir}/davfs2/davfs2.conf
%config(noreplace) %{_sysconfdir}/davfs2/secrets
%dir %{_sysconfdir}/davfs2/certs/private/
%dir %{_sysconfdir}/davfs2/certs/
%dir %{_sysconfdir}/davfs2/
%dir %{_datarootdir}/davfs2/
%{_datarootdir}/davfs2/*

# Binaries
%{_sbindir}/umount.davfs
# re-apply suid bit to mount.davfs
%attr (4755,root,root) %{_sbindir}/mount.davfs

# Extra dirs needed by mount.davfs
%ghost %dir %attr(00775,root,%{groupname}) %{cachedir}
%ghost %dir %attr(01775,root,%{groupname}) %{piddir}

%if 0%{?rhel} == 6
/sbin/mount.davfs
/sbin/umount.davfs
%endif

%changelog
* Mon Oct 13 2014 Moez Roy <moez.roy@gmail.com> - 1.4.7-8
-Add symlink in /sbin pointing to /usr/sbin for el6

* Sat Oct 11 2014 Moez Roy <moez.roy@gmail.com> - 1.4.7-6
-Add global harderning flags - RHBZ 965511
-RHBZ 1151273 - davfs2 conflicts with filesystem-2.4.30-3.el6.x86_64

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.7-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Sep 19 2013 Will Woods <wwoods@redhat.com> - 1.4.7-3
- CVE-2013-4362: Fix possibly insecure use of system()

* Fri Sep 13 2013 Paul Howarth <paul@city-fan.org> - 1.4.7-2
- Add support for building with neon 0.30.0 (#992110)
- Use -fno-strict-aliasing

* Tue Feb 26 2013 Erik Logtenberg <erik@logtenberg.eu> - 1.4.7-1
- New upstream release
- The check for somebody else's home directory is gone. So you should
  be able to mount in /media/foo even if / is the home of some daemon.

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.6-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jun 2 2012 Will Woods <wwoods@redhat.com> 1.4.6-4
- Mark /var/cache/davfs2 and /var/run/mount.davfs %%ghost (#656570)
- Fix 'cannot stat `/usr/share/davfs2/davfs2.conf'' warning (#783788)

* Wed Jan 25 2012 Harald Hoyer <harald@redhat.com> 1.4.6-3
- install everything in /usr
  https://fedoraproject.org/wiki/Features/UsrMove

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Nov 09 2011 Will Woods <wwoods@redhat.com> - 1.4.6-1
- New upstream release. From the upstream changelog:
- Fix assignment of password from pam_mount (bug #28706)
- Fix log messages in dav_create

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Feb 15 2010 Will Woods <wwoods@redhat.com> - 1.4.5-2
- Add davfs2-1.4.5-sys_stat_h.patch to fix building on F13

* Wed Jan 13 2010 Will Woods <wwoods@redhat.com> - 1.4.5-1
- New upstream release (fixes rebuild failure, see bug 538913)
- NOTE: 1.4.x has different config file syntax. Read the NEWS file!

* Thu Sep 17 2009 Peter Lemenkov <lemenkov@gmail.com> - 1.3.3-5
- bump

* Thu Sep 17 2009 Peter Lemenkov <lemenkov@gmail.com> - 1.3.3-4
- Rebuilt with new fuse

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Mar 11 2009 Will Woods <wwoods@redhat.com> - 1.3.3-2
- Passed package review (#488858)
- Ensure that package owns /etc/davfs2 and /etc/davfs2/certs

* Mon Mar 02 2009 Will Woods <wwoods@redhat.com> - 1.3.3-1
- Initial packaging
- Fix open() with O_CREAT and no mode
